pyMaBoSS
========

pyMaBoSS is a python API for the `MaBoSS <https://maboss.curie.fr/>`_ software.
It can be used inside the `Colomoto docker <https://hub.docker.com/r/colomoto/colomoto-docker/>`_.
The API is loaded by running the following line in Python::
    import maboss


Tutorial
--------
.. toctree::
   :maxdepth: 2

   Tutorial.ipynb

API
---
.. toctree::
   :maxdepth: 2

   api.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
